from django.urls import path

from .views import user_views, requirements_views, main_req_views

urlpatterns = [
    path('users/', user_views.UserList.as_view(), name='api-user-list'),
    path('users/<uuid:pk>/', user_views.UserDetail.as_view(), name='api-post-details'),
    path('requirements/', requirements_views.BoilerplateListCreateAPIView.as_view(), name='api-requirements-list'),
    path('requirements/<int:pk>/', requirements_views.BoilerplateDetailsAPIView.as_view(), name='api-requirements-details'),
    
    #'''Prefix'''
    path('requirements/<int:boilerplate>/prefix/', requirements_views.PrefixListCreateAPIView.as_view(), name='api-prefix-list'),
    path('requirements/<int:boilerplate>/prefix/<int:pk>/', requirements_views.PrefixDetailsAPIView.as_view(), name='api-prefix-details'),
    #'''P1'''
    path('requirements/<int:boilerplate>/prefix/<int:prefixs>/p1/', requirements_views.LogicalExpressionListCreateAPIView.as_view(), name='api-log_expr-list'),
    path('requirements/<int:boilerplate>/prefix/<int:prefixs>/p1/<int:pk>/', requirements_views.LogicalExpressionDetailsAPIView.as_view(), name='api-log_expr-details'),
    #'''P2'''
    path('requirements/<int:boilerplate>/prefix/<int:prefixs>/p2/', requirements_views.OccuringFunctionalityP2ListCreateAPIView.as_view(), name='api-occur_func-list'),
    path('requirements/<int:boilerplate>/prefix/<int:prefixs>/p2/<int:pk>/', requirements_views.OccuringFunctionalityP2DetailsAPIView.as_view(), name='api-occur_func-details'),
    #'''P3'''
    path('requirements/<int:boilerplate>/prefix/<int:prefixs>/p3/', requirements_views.OccuringFunctionalityP3ListCreateAPIView.as_view(), name='api-occur_func_p3-list'),
    path('requirements/<int:boilerplate>/prefix/<int:prefixs>/p3/<int:pk>/', requirements_views.OccuringFunctionalityP3DetailsAPIView.as_view(), name='api-occur_func_p3-details'),
    #'''Logical expression of P1'''
    path('requirements/<int:boilerplate>/prefix/<int:prefixs>/p1/<int:log_expr>/constraint/', requirements_views.StateValueConstraintListCreateAPIView.as_view(), name='api-constraint-list'),
    path('requirements/<int:boilerplate>/prefix/<int:prefixs>/p1/<int:log_expr>/constraint/<int:pk>/', requirements_views.StateValueConstraintDetailsAPIView.as_view(), name='api-constraint-details'),
    #'''Occuring functionality of P1'''
    path('requirements/<int:boilerplate>/prefix/<int:prefixs>/p1/<int:log_expr>/functionality/', requirements_views.OccuringFunctionalityForLogicalExpressionListCreateAPIView.as_view(), name='api-functionality-for-log-list'),
    path('requirements/<int:boilerplate>/prefix/<int:prefixs>/p1/<int:log_expr>/functionality/<int:pk>/', requirements_views.OccuringFunctionalityForLogicalExpressionDetailsAPIView.as_view(), name='api-functionality-for-log-list'),

    #'''MAIN'''
    path('requirements/<int:boilerplate>/main/', main_req_views.MainListCreateAPIView.as_view(), name='api-main-list'),
    path('requirements/<int:boilerplate>/main/<int:pk>/', main_req_views.MainDetailsAPIView.as_view(), name='api-main-details'),
    #'''M1'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m1/', main_req_views.Main_M1ListCreateAPIView.as_view(), name='api-main-m1-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m1/<int:pk>/', main_req_views.Main_M1DetailsAPIView.as_view(), name='api-main-m1-details'),
    #'''M2'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m2/', main_req_views.Main_M2ListCreateAPIView.as_view(), name='api-main-m2-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m2/<int:pk>/', main_req_views.Main_M2DetailsAPIView.as_view(), name='api-main-m2-details'),
    #'''M3'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m3/', main_req_views.Main_M3ListCreateAPIView.as_view(), name='api-main-m3-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m3/<int:pk>/', main_req_views.Main_M3DetailsAPIView.as_view(), name='api-main-m3-details'),
    #'''M4'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m4/', main_req_views.Main_M4ListCreateAPIView.as_view(), name='api-main-m4-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m4/<int:pk>/', main_req_views.Main_M4DetailsAPIView.as_view(), name='api-main-m4-details'),
    #'''M5'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m5/', main_req_views.Main_M5ListCreateAPIView.as_view(), name='api-main-m5-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m5/<int:pk>/', main_req_views.Main_M5DetailsAPIView.as_view(), name='api-main-m5-details'),
    #'''M6'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m6/', main_req_views.Main_M6ListCreateAPIView.as_view(), name='api-main-m6-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m6/<int:pk>/', main_req_views.Main_M6DetailsAPIView.as_view(), name='api-main-m6-details'),
    #'''M7'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m7/', main_req_views.Main_M7ListCreateAPIView.as_view(), name='api-main-m7-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m7/<int:pk>/', main_req_views.Main_M7DetailsAPIView.as_view(), name='api-main-m7-details'),
    #'''M8'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m8/', main_req_views.Main_M8ListCreateAPIView.as_view(), name='api-main-m8-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m8/<int:pk>/', main_req_views.Main_M8DetailsAPIView.as_view(), name='api-main-m8-details'),
    #'''M9'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m9/', main_req_views.Main_M9ListCreateAPIView.as_view(), name='api-main-m9-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m9/<int:pk>/', main_req_views.Main_M9DetailsAPIView.as_view(), name='api-main-m9-details'),
    #'''M10'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m10/', main_req_views.Main_M10ListCreateAPIView.as_view(), name='api-main-m10-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m10/<int:pk>/', main_req_views.Main_M10DetailsAPIView.as_view(), name='api-main-m10-details'),
    #'''M11'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m11/', main_req_views.Main_M11ListCreateAPIView.as_view(), name='api-main-m11-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m11/<int:pk>/', main_req_views.Main_M11DetailsAPIView.as_view(), name='api-main-m11-details'),
    #'''M12'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m12/', main_req_views.Main_M12ListCreateAPIView.as_view(), name='api-main-m12-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m12/<int:pk>/', main_req_views.Main_M12DetailsAPIView.as_view(), name='api-main-m12-details'),
    #'''M13'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m13/', main_req_views.Main_M13ListCreateAPIView.as_view(), name='api-main-m13-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m13/<int:pk>/', main_req_views.Main_M13DetailsAPIView.as_view(), name='api-main-m13-details'),
    #'''M14'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m14/', main_req_views.Main_M14ListCreateAPIView.as_view(), name='api-main-m14-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m14/<int:pk>/', main_req_views.Main_M14DetailsAPIView.as_view(), name='api-main-m14-details'),
    #'''M15'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m15/', main_req_views.Main_M15ListCreateAPIView.as_view(), name='api-main-m15-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m15/<int:pk>/', main_req_views.Main_M15DetailsAPIView.as_view(), name='api-main-m15-details'),
    #'''M16'''
    path('requirements/<int:boilerplate>/main/<int:mains>/m16/', main_req_views.Main_M16ListCreateAPIView.as_view(), name='api-main-m16-list'),
    path('requirements/<int:boilerplate>/main/<int:mains>/m16/<int:pk>/', main_req_views.Main_M16DetailsAPIView.as_view(), name='api-main-m16-details'),

]